import { navbar } from '../../../../../utils/navbar.js';
import { readFile } from 'fs/promises';
import { permissionBits, checkPermissions } from '../../../../../utils/permissions.js';

export default {
    path: "/dashboard/users/list",
    requiresLogin: true,
    permissions: permissionBits.ADMIN,
    type: "get",
    async execute(request, response) {
        const userList = await global.database.users.findAll();
        const userTable = genUserTable(userList);
        const html = await readFile(`${process.env.WWW}/dashboard/users/list.html`);            
        return await response.send(html.toString()
            .replace('<NAVBAR>', navbar(request.session))
            .replace('<USERTABLE>', userTable)
        );
    },
}

function genUserTable(users) {
    let res = `
      <table>
        <tr>
          <th>Identifiant</th>
          <th>Permissions</th>
          <th>Action</th>
        </tr>`;
    for(const user of users) {
        const userPermDict = checkPermissions(user.permissions);
        let userPerms = [];
        for (const [key, value] of Object.entries(userPermDict)) {
            if(value && key != "default") userPerms.push(key);
        };
        res += `
        <tr>
          <td><a href='./${user.username}'>${user.username}</a></td>
          <td>${userPerms.join(", ")}</td>
          <td><button onclick="deleteUser('${user.username}');">Supprimer</button></td>
        </tr>`;
    }
    res += `</table>`;
    return res
}
