import {
    permissionBits,
    checkPermissions,
} from "../../../../../utils/permissions.js";
import { readFile } from "fs/promises";
import { navbar } from "../../../../../utils/navbar.js";

export default {
    path: "/dashboard/users/:username",
    requiresLogin: true,
    permissions: permissionBits.ADMIN,
    type: "get",
    async execute(request, response) {
        const { username } = request.params;
        const user = await global.database.users.findOne({
            where: { username: username },
        });
        if (!user) return response.redirect("/dashboard/users");
        const html = await readFile(
            `${process.env.WWW}/dashboard/users/info.html`,
        );
        response.send(
            html
                .toString()
                .replace("<NAVBAR>", navbar(request.session))
                .replace("<USERINFO>", getUserHTML(user)),
        );
    },
};

function getUserHTML(user) {
    const userPermDict = checkPermissions(user.permissions);
    let userPerms = [];
    for (const [key, value] of Object.entries(userPermDict)) {
        if (value && key != "default") userPerms.push(key);
    }
    let res = `
      <table>
        <tr>
          <th>Identifiant</th>
          <th>Permissions</th>
          <th>Action</th>
        </tr>
        <tr>
          <td>${user.username}</td>
          <td>${userPerms.join(", ")}</td>
          <td><button onclick="deleteUser('${user.username}');">Supprimer</button></td>
        </tr>
      </table>`;
    return res;
}
