import { generateCallHTML } from "../../../../src/html/callHTML.js";
import { getRandomUser } from '../../../../src/database/getUser.js';
import { navbar } from '../../../../utils/navbar.js';
import { permissionBits } from "../../../../utils/permissions.js";

export default {
    path: "/calls",
    requiresLogin: true,
    permissions: permissionBits.CALL,
    type: "get",
    async execute(request, response) {
        const res = await generateCallResponse(request.session);
        response.send(res.replaceAll("<NAVBAR>", navbar(request.session)));
    },
}

async function generateCallResponse(session) {
    const user = await getRandomUser();
    let callHTML;
    if (user) callHTML = generateCallHTML(user.phone, user.name, user.count, session);
    else callHTML = `
      <!DOCTYPE html>
      <html>
      <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta http-equiv="X-UA-Compatible" content="ie=edge">
        <link rel="stylesheet" type="text/css" href="/assets/css/form.css" />
        <title>AutoCallMenu</title>
      </head>
      <body>
        <NAVBAR>
        <h1>Bienvenue :3</h1>
        <h2>0 appels restants !</h2>
      </body>
      </html>`;
    return callHTML;
}
