import express from "express";
import session from "express-session";
import { deployHandler } from "./utils/handler.js";
import favicon from "serve-favicon";
import vhost from "vhost";

async function launchWeb() {
    const app = express();
    const routerApp = express();

    app.use(express.json()); // Used to parse JSON bodies
    app.use(express.urlencoded({ extended: false })); //Parse URL-encoded bodies
    app.use(
        session({
            secret: process.env.SECRET,
            resave: false,
            saveUninitialized: true,
        }),
    );
    routerApp.use(vhost(`${process.env.SERVER_URL}`, app));

    app.use("/assets", express.static(`${process.env.WWW}/assets`));
    app.use(favicon(`${process.env.WWW}/assets/images/favicon.ico`));

    await deployHandler(app);

    const PORT = process.env.PORT || 3000;
    routerApp.listen(PORT, () => {
        console.log(
            `App available at http://${process.env.SERVER_URL}:${PORT}`,
        );
    });
}

export { launchWeb };
